<h3><i class="fa fa-{{plugin.icon}}"></i> {{plugin.title}}</h3>

<progress-spinner ng:show="!plugin"></progress-spinner>

<div class="form-horizontal" ng:show="plugin">
    <div class="form-group">
        <label class="col-sm-2 control-label" translate>Name</label>
        <div class="col-sm-10">
            <label class="form-control-static">
                {{plugin.name}}
            </label>
        </div>
    </div>
    <div class="form-group">
        <label class="col-sm-2 control-label" translate>Title</label>
        <div class="col-sm-10">
            <label class="form-control-static">
                {{plugin.title}}
            </label>
        </div>
    </div>
    <div class="form-group">
        <label class="col-sm-2 control-label" translate>Version</label>
        <div class="col-sm-10">
            <label class="form-control-static">
                {{plugin.version}}
            </label>
        </div>
    </div>
    <div class="form-group">
        <label class="col-sm-2 control-label">PyPI ID</label>
        <div class="col-sm-10">
            <label class="form-control-static">
                {{plugin.pypi_name}}
            </label>
        </div>
    </div>
    <div class="form-group">
        <label class="col-sm-2 control-label" translate>Downloads this month</label>
        <div class="col-sm-10">
            <label class="form-control-static">
                {{plugin.last_month_downloads}}
            </label>
        </div>
    </div>
    <div class="form-group">
        <label class="col-sm-2 control-label" translate>Author</label>
        <div class="col-sm-10">
            <label class="form-control-static">
                {{plugin.author}}
                <div ng:show="plugin.author_email">
                    <span class="subtle">{{plugin.author_email}}</span>
                </div>
                <div ng:show="plugin.url">
                    <a href="{{plugin.url}}" target="_blank" translate>Homepage</a> <i class="fa fa-external-link-square"></i>
                </div>
            </label>
        </div>
    </div>
</div>