{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Ajenti \u5185\u6838 {{ajentiVersion}}\uff0c\u6ca1\u6709\u8981\u66f4\u65b0\u7684\u5185\u5bb9\u3002", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "Ajenti \u6838\u5fc3 {{ajentiVersion}}\u3002\u53ef\u4ee5\u66f4\u65b0\u5230 {{coreUpgradeAvailable}} \u3002", "Author": "\u4f5c\u8005", "Available plugins": "\u53ef\u7528\u7684\u63d2\u4ef6", "Close": "\u5173\u95ed", "Community": "\u793e\u533a", "Core": "\u6838\u5fc3", "Downloads in the last month": "\u4e0a\u4e2a\u6708\u7684\u4e0b\u8f7d\u91cf", "Downloads this month": "\u672c\u6708\u4e0b\u8f7d\u91cf", "Error": "\u9519\u8bef", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "\u4f8b\u5916: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Filter": "\u8fc7\u6ee4\u5668", "Homepage": "\u4e3b\u9875", "Install": "\u5b89\u88c5", "Installed plugins": "\u5df2\u5b89\u88c5\u7684\u63d2\u4ef6", "Loading error": "\u52a0\u8f7d\u51fa\u9519", "Location": "\u4f4d\u7f6e", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "\u4fe1\u606f: <code>{{selectedInstalledPlugin.crash.message}}</code>", "Name": "\u540d\u79f0", "Official": "\u5b98\u65b9", "Restart panel": "\u91cd\u542f\u9762\u677f", "This plugin crashed with the following error:": "\u8fd9\u4e2a\u63d2\u4ef6\u7531\u4e8e\u4ee5\u4e0b\u9519\u8bef\u5d29\u6e83:", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "\u63d2\u4ef6\u542f\u52a8\u6240\u9700\u8981\u7684\u7a0b\u5e8f\u7ec4\u4ef6\u4e0d\u53ef\u7528 <code>{{selectedInstalledPlugin.crash.binaryName}}</code>\u3002", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "\u8be5\u63d2\u4ef6\u542f\u52a8\u9700\u8981\u7684\u63d2\u4ef6\u4e0d\u53ef\u7528 <code>{{selectedInstalledPlugin.crash.pluginName}}</code>\u3002", "Title": "\u6807\u9898", "Uninstall": "\u5378\u8f7d", "Update": "\u66f4\u65b0", "Update everything": "\u5168\u90e8\u66f4\u65b0", "Updates": "\u66f4\u65b0", "Upgradeable to {{getUpgrade(plugin).version}}": "\u53ef\u5347\u7ea7\u5230 {{getUpgrade (plugin).version}}", "Version": "\u7248\u672c", "Plugins": "\u63d2\u4ef6", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}