{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Ajenti core \ubc84\uc804 {{ajentiVersion}}, \uc5c5\uadf8\ub808\uc774\ub4dc\uac00 \uc5c6\uc2b5\ub2c8\ub2e4.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "Ajenti core \ubc84\uc804 {{ajentiVersion}}. \uc5c5\uadf8\ub808\uc774\ub4dc \ubc84\uc804 {{coreUpgradeAvailable}} \uc774 \uc788\uc2b5\ub2c8\ub2e4.", "Author": "\ub9cc\ub4e0 \uc0ac\ub78c", "Available plugins": "\uc0ac\uc6a9 \uac00\ub2a5\ud55c \ud50c\ub7ec\uadf8\uc778", "Close": "\ub2eb\uae30", "Community": "\ucee4\ubba4\ub2c8\ud2f0", "Core": "\ucf54\uc5b4", "Downloads in the last month": "\uc9c0\ub09c \ub2ec \ub2e4\uc6b4\ub85c\ub4dc", "Downloads this month": "\uc774\ubc88\ub2ec \ub2e4\uc6b4\ub85c\ub4dc", "Error": "\uc5d0\ub7ec", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "\uc608\uc678: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Filter": "\ud544\ud130", "Homepage": "\ud648\ud398\uc774\uc9c0", "Install": "\uc124\uce58", "Installed plugins": "\uc124\uce58\ub41c \ud50c\ub7ec\uadf8\uc778", "Loading error": "\ub85c\ub4dc \uc5d0\ub7ec", "Location": "\uc704\uce58", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "\uba54\uc2dc\uc9c0: <code>{{selectedInstalledPlugin.crash.message}}</code>", "Name": "\uc774\ub984", "Official": "\uacf5\uc2dd", "Restart panel": "\ud328\ub110\uc744 \ub2e4\uc2dc \uc2dc\uc791", "This plugin crashed with the following error:": "", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "", "Title": "\uc81c\ubaa9", "Uninstall": "\uc0ad\uc81c", "Update": "\uc5c5\ub370\uc774\ud2b8", "Update everything": "\ubaa8\ub4e0 \uac83\uc744 \uc5c5\ub370\uc774\ud2b8", "Updates": "\uc5c5\ub370\uc774\ud2b8", "Upgradeable to {{getUpgrade(plugin).version}}": "", "Version": "\ubc84\uc804", "Plugins": "\ud50c\ub7ec\uadf8\uc778", "Could not load repository version for ajenti-panel.": "ajenti-panel\uc5d0 \ub300\ud55c \uc800\uc7a5\uc18c \ubc84\uc804\uc744 \ubd88\ub7ec\uc62c \uc218 \uc5c6\uc2b5\ub2c8\ub2e4", "Could not load plugin repository": "\ud50c\ub7ec\uadf8\uc778 \uc800\uc7a5\uc18c\ub97c \ubd88\ub7ec\uc62c \uc218 \uc5c6\uc2b5\ub2c8\ub2e4", "Could not load the installed plugin list": "\uc124\uce58 \ub41c \ud50c\ub7ec\uadf8\uc778 \ubaa9\ub85d\uc744 \ubd88\ub7ec\uc62c \uc218 \uc5c6\uc2b5\ub2c8\ub2e4.", "All plugins updated": "\ubaa8\ub4e0 \ud50c\ub7ec\uadf8\uc778 \uc5c5\ub370\uc774\ud2b8", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}