{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Ajenti core {{ajentiVersion}}, geen upgrades beschikbaar.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "Ajenti core {{ajentiVersion}}. Een upgrade naar {{coreUpgradeAvailable}} is beschikbaar.", "Author": "Auteur", "Available plugins": "Beschikbare PlugIns", "Close": "Sluiten", "Community": "Gemeenschap", "Core": "Core", "Downloads in the last month": "Downloads afgelopen maand", "Downloads this month": "Downloads deze maand", "Error": "Fout", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "", "Filter": "", "Homepage": "", "Install": "Installeren", "Installed plugins": "Ge\u00efnstalleerde plug-ins", "Loading error": "Fout tijdens het laden", "Location": "Locatie", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "Bericht: <code>{{selectedInstalledPlugin.crash.message}}</code>", "Name": "Naam", "Official": "Officieel", "Restart panel": "Herstart paneel", "This plugin crashed with the following error:": "Deze plugin crashte met de volgende foutcode:", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "Deze plugin vereist plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, die tijdens het opstarten niet beschikbaar was.", "Title": "Aanhef", "Uninstall": "Deinstalleer", "Update": "Bijwerken", "Update everything": "Alles bijwerken", "Updates": "Updates", "Upgradeable to {{getUpgrade(plugin).version}}": "Up te daten naar versie {{getUpgrade(plugin).version}}", "Version": "Versie", "Plugins": "Plugins", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}