{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Ajenti core {{ajentiVersion}}, n\u00e3o h\u00e1 atualiza\u00e7\u00f5es dispon\u00edveis.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "Ajenti core {{ajentiVersion}}. Uma atualiza\u00e7\u00e3o para {{coreUpgradeAvailable}} est\u00e1 dispon\u00edvel.", "Author": "Autor", "Available plugins": "Plugins Dispon\u00edveis", "Close": "Fechar", "Community": "Comunidade", "Core": "N\u00facleo", "Downloads in the last month": "Downloads no \u00faltimo m\u00eas", "Downloads this month": "Downloads este m\u00eas", "Error": "Erro", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "Excess\u00e3o:<c\u00f3digo>{{Plugininstaladoselecionado.colis\u00e3o.cls}}</c\u00f3digo>", "Filter": "Filtro", "Homepage": "P\u00e1gina Inicial", "Install": "Instalar", "Installed plugins": "Plugins instalados", "Loading error": "Erro ao carregar", "Location": "Localiza\u00e7\u00e3o", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "Mensagem:<c\u00f3digo>{{Plugininstaladoselecionado.colis\u00e3o.mensagem}}</c\u00f3digo>", "Name": "Nome", "Official": "Oficial", "Restart panel": "Reiniciar painel", "This plugin crashed with the following error:": "Este plugin falhou com a seguinte menagem de erro:", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "Este plugin requer aplicativo bin\u00e1rio <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, que n\u00e3o estava dispon\u00edvel durante a inicializa\u00e7\u00e3o.", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "Este plugin requer o plugin <c\u00f3digo>{{Plugininstaladoselecionado.colis\u00e3o.nomedoplugin}}</c\u00f3digo>, que n\u00e3o estava dispon\u00edvel durante a inicializa\u00e7\u00e3o", "Title": "T\u00edtulo", "Uninstall": "Desinstalar", "Update": "Atualizar", "Update everything": "Atualizar tudo", "Updates": "Atualiza\u00e7\u00f5es", "Upgradeable to {{getUpgrade(plugin).version}}": "Atualiz\u00e1vel para Upgradeable to {{getUpgrade(plugin).version}}", "Version": "Vers\u00e3o", "Plugins": "Plugins", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}