{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Ajenti jedro {{ajentiVersion}}, na voljo ni nobena nadgradnja.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "Jedro {{ajentiVersion}} Ajenti. Nadgradnja na {{coreUpgradeAvailable}} je na voljo.", "Author": "Avtor", "Available plugins": "Vti\u010dniki, ki so na voljo", "Close": "Zapri", "Community": "Skupnost", "Core": "Jedro", "Downloads in the last month": "Prenosi v zadnjem mesecu", "Downloads this month": "Prenosi ta mesec", "Error": "Napaka", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "Izjema: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Filter": "Filter", "Homepage": "Doma\u010da stran", "Install": "Namesti", "Installed plugins": "Name\u0161\u010deni vti\u010dniki", "Loading error": "Napaka pri nalaganju", "Location": "Lokacija", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "Sporo\u010dilo: <code>{{selectedInstalledPlugin.crash.message}}</code>", "Name": "Ime", "Official": "Uradno", "Restart panel": "Ponovno za\u017eeni plo\u0161\u010do", "This plugin crashed with the following error:": "Ta vti\u010dnik se je sesul zaradi naslednje napake:", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "Ta vti\u010dnik zahteva vti\u010dnik<code>{{selectedInstalledPlugin.crash.pluginName}}</code>, ki ni bil na voljo med zagonom.", "Title": "Nalov", "Uninstall": "Odstranitev", "Update": "Posodobitev", "Update everything": "Posodobi vse", "Updates": "Posodobitve", "Upgradeable to {{getUpgrade(plugin).version}}": "Nadgradljivo na {{getUpgrade (plugin).version}}", "Version": "Razli\u010dica", "Plugins": "Vti\u010dniki", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}