{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Nessun aggiornamento disponibile per Ajenti core {{ajentiVersion}}.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "\u00c8 disponibile un aggiornamento per Ajenti core {{ajentiVersion}} alla versione {{coreUpgradeAvailable}}.", "Author": "Autore", "Available plugins": "Plugin disponibili", "Close": "Chiudi", "Community": "Community", "Core": "Core", "Downloads in the last month": "Scaricati nell'ultimo mese", "Downloads this month": "Scaricati questo mese", "Error": "Errore", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "Eccezione: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Filter": "Filtro", "Homepage": "Home page", "Install": "Installa", "Installed plugins": "Plugin installati", "Loading error": "Errore di caricamento", "Location": "Posizione", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "Messaggio: <code>{{selectedInstalledPlugin.crash.message}}</code>", "Name": "Nome", "Official": "Ufficiale", "Restart panel": "Riavvia il pannello", "This plugin crashed with the following error:": "Questo plugin si \u00e8 bloccato con il seguente errore:", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "Questo plugin richiede l'applicazione <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, non disponibile durante l'avvio.", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "Questo plugin richiede il plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, non disponibile durante l'avvio.", "Title": "Titolo", "Uninstall": "Disinstalla", "Update": "Aggiorna", "Update everything": "Aggiorna tutto", "Updates": "Aggiornamenti", "Upgradeable to {{getUpgrade(plugin).version}}": "Aggiornabile alla versione {{. Version getUpgrade (plugin)}}", "Version": "Versione", "Plugins": "Plugin", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}