{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Ajenti Kern {{ajentiVersion}}, keine Upgrades verf\u00fcgbar.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "Ajenti Core {{ajentiVersion}}. Ein Upgrade auf {{coreUpgradeAvailable}} ist verf\u00fcgbar.", "Author": "Author", "Available plugins": "Verf\u00fcgbare Plugins", "Close": "Schlie\u00dfen", "Community": "Community", "Core": "Core", "Downloads in the last month": "Downloads im letzten Monat", "Downloads this month": "Downloads in diesem Monat", "Error": "Fehler", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "Ausnahme: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Filter": "Filter", "Homepage": "Homepage", "Install": "Installieren", "Installed plugins": "Installierte Plugins", "Loading error": "Ladefehler", "Location": "Ort", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "Nachricht: <code>{{selectedInstalledPlugin.crash.message}}</code>", "Name": "Name", "Official": "Offiziell", "Restart panel": "Panel neustarten", "This plugin crashed with the following error:": "Das Plugin ist mit dem folgenden Fehler abgest\u00fcrzt:", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "Dieses Plugin erfordert die bin\u00e4re Anwendung <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, die w\u00e4hrend des Startvorgangs nicht verf\u00fcgbar war.", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "Dieses Plugin ben\u00f6tigt das Plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, das w\u00e4hrend des Startvorgangs nicht verf\u00fcgbar war.", "Title": "Titel", "Uninstall": "Deinstallieren", "Update": "Aktualisierung", "Update everything": "Alles aktualisieren", "Updates": "Aktualisierungen", "Upgradeable to {{getUpgrade(plugin).version}}": "Aktualisierbar auf {{getUpgrade(plugin).version}}", "Version": "Version", "Plugins": "Erweiterungen", "Could not load repository version for ajenti-panel.": "Konnte die Repository-Version f\u00fcr das ajenti-Panel nicht laden.", "Could not load plugin repository": "Plugin-Verzeichnis konnte nicht geladen werden", "Could not load the installed plugin list": "Konnte die installierte Plugin-Liste nicht laden", "All plugins updated": "Alle Plugins aktualisiert", "Done": "Erledigt", "Installed. A panel restart is required.": "Installiert. Ein Panel-Neustart ist erforderlich.", "Restart now": "Jetzt neu starten", "Later": "Sp\u00e4ter", "Some plugins failed to update": "Einige Plugins konnten nicht aktualisiert werden", "Install failed": "Installation fehlgeschlagen", "Warning": "Warnung", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "Dadurch wird das Plugin-Plugin entfernt. Sie k\u00f6nnen es sp\u00e4ter mit PIP neu installieren.", "Continue": "Fortfahren", "Cancel": "Abbrechen", "Uninstalling": "Deinstalliere", "Uninstalled. A panel restart is required.": "Deinstalliert. Ein Panel-Neustart ist erforderlich.", "Uninstall failed": "Deinstallation fehlgeschlagen"}