{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Ajenti core {{ajentiVersion}}, brak dost\u0119pnych aktualizacji.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "Ajenti core {{ajentiVersion}}. Dost\u0119pne jest uaktualnienie do wersji {{coreUpgradeAvailable}}.", "Author": "Autor", "Available plugins": "Dost\u0119pne wtyczki", "Close": "Zamknij", "Community": "Spo\u0142eczno\u015b\u0107", "Core": "Rdze\u0144", "Downloads in the last month": "Downloads w ostatnim miesi\u0105cu", "Downloads this month": "Downloads w tym miesi\u0105cu", "Error": "B\u0142\u0105d", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "Wyj\u0105tek: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Filter": "Filtr", "Homepage": "Strona g\u0142\u00f3wna", "Install": "Zainstaluj", "Installed plugins": "Zainstalowane wtyczki", "Loading error": "B\u0142\u0105d \u0142adowania", "Location": "Lokacja", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "Wiadomo\u015b\u0107: <code>{{selectedInstalledPlugin.crash.message}}</code>", "Name": "Nazwa", "Official": "Oficjalny", "Restart panel": "Ponownie uruchomi\u0107 panel", "This plugin crashed with the following error:": "", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "", "Title": "Tytu\u0142", "Uninstall": "Odinstaluj", "Update": "Aktualizuj", "Update everything": "Aktualizuj wszystko", "Updates": "Aktualizacje", "Upgradeable to {{getUpgrade(plugin).version}}": "", "Version": "Wersja", "Plugins": "Pluginy", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}