{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "J\u00e1dro Ajenti {{ajentiVersion}}, \u017e\u00e1dn\u00e9 aktualizace nejsou k dispozici.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "J\u00e1dro Ajenti {{ajentiVersion}}. K dispozici aktualizace na {{coreUpgradeAvailable}}.", "Author": "Autor", "Available plugins": "Dostupn\u00e9 dopl\u0148ky", "Close": "Zav\u0159\u00edt", "Community": "Komunita", "Core": "J\u00e1dro", "Downloads in the last month": "Sta\u017een\u00ed za posledn\u00ed m\u011bs\u00edc", "Downloads this month": "Sta\u017een\u00ed tento m\u011bs\u00edc", "Error": "Chyba", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Filter": "Filtr", "Homepage": "Domovsk\u00e1 str\u00e1nka", "Install": "Instalovat", "Installed plugins": "Nainstalovan\u00e9 moduly", "Loading error": "Chyba p\u0159i na\u010d\u00edt\u00e1n\u00ed", "Location": "Um\u00edst\u011bn\u00ed", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "Zpr\u00e1va: <code>{{selectedInstalledPlugin.crash.message}}</code>", "Name": "Jm\u00e9no", "Official": "Ofici\u00e1ln\u00ed", "Restart panel": "Restartovat panel", "This plugin crashed with the following error:": "Tento dopln\u011bk selhal s n\u00e1sleduj\u00edc\u00ed chybou:", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "Tento modul vy\u017eaduje binary aplikace <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, kter\u00e9 bylo nedostupn\u00e9 p\u0159i spu\u0161t\u011bn\u00ed.", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "Tento modul vy\u017eaduje modul <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, kter\u00e9 bylo nedostupn\u00e9 p\u0159i spu\u0161t\u011bn\u00ed.", "Title": "N\u00e1zev", "Uninstall": "Odinstalovat", "Update": "Aktualizovat", "Update everything": "Aktualizovat v\u0161e", "Updates": "Aktualizace", "Upgradeable to {{getUpgrade(plugin).version}}": "Aktualizovateln\u00e1 a\u017e na {{getUpgrade(plugin).version}}", "Version": "Verze", "Plugins": "Z\u00e1suvn\u00e9 moduly", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}