{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Jadro Ajenti {{ajentiVersion}}, \u017eiadne dostupn\u00e9 aktualiz\u00e1cie.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "", "Author": "Autor", "Available plugins": "Dostupn\u00e9 doplnky", "Close": "Zavrie\u0165", "Community": "Komunita\u200b", "Core": "Jadro", "Downloads in the last month": "Prevzatia za posledn\u00fd mesiac", "Downloads this month": "Stiahnutia v tomto mesiaci", "Error": "Chyba", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "", "Filter": "Filtrova\u0165", "Homepage": "Domovsk\u00e1 str\u00e1nka", "Install": "In\u0161talova\u0165", "Installed plugins": "In\u0161talovan\u00e9 doplnky", "Loading error": "Na\u010d\u00edtanie zlyhalo", "Location": "Poloha", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "", "Name": "Meno", "Official": "Ofici\u00e1lne", "Restart panel": "Re\u0161tartova\u0165 panel", "This plugin crashed with the following error:": "Tento doplnok prestal pracova\u0165 z nasleduj\u00faceho d\u00f4vodu:", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "", "Title": "", "Uninstall": "", "Update": "", "Update everything": "", "Updates": "", "Upgradeable to {{getUpgrade(plugin).version}}": "", "Version": "", "Plugins": "", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}