{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "", "Author": "", "Available plugins": "", "Close": "Fermarh", "Community": "", "Core": "", "Downloads in the last month": "", "Downloads this month": "", "Error": "", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "", "Filter": "", "Homepage": "", "Install": "Installarh", "Installed plugins": "", "Loading error": "", "Location": "", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "", "Name": "N\u00f3mina", "Official": "", "Restart panel": "", "This plugin crashed with the following error:": "", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "", "Title": "", "Uninstall": "", "Update": "", "Update everything": "", "Updates": "", "Upgradeable to {{getUpgrade(plugin).version}}": "", "Version": "", "Plugins": "", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}