{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Noyau Ajenti {{ajentiVersion}}, pas de mise \u00e0 jour disponible.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "Noyau Ajenti {{ajentiVersion}}. Une mise \u00e0 jour vers {{coreUpgradeAvailable}} est disponible.", "Author": "Auteur", "Available plugins": "Extensions disponibles", "Close": "Fermer", "Community": "Communaut\u00e9", "Core": "Noyau", "Downloads in the last month": "T\u00e9l\u00e9chargements lors du dernier mois", "Downloads this month": "T\u00e9l\u00e9chargements de ce mois", "Error": "Erreur", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Filter": "Filtre", "Homepage": "Page d'accueil", "Install": "Installer", "Installed plugins": "Extensions install\u00e9s", "Loading error": "Erreur de chargement", "Location": "Emplacement", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>", "Name": "Nom", "Official": "Officiel", "Restart panel": "Red\u00e9marrer le panneau", "This plugin crashed with the following error:": "Cette extension a plant\u00e9 avec l'erreur suivante :", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "Cette extension n\u00e9cessite l'application binaire <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, qui n'\u00e9tait pas disponible lors du d\u00e9marrage.", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "Cette extension n\u00e9cessite l'extension <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, qui n'\u00e9tait pas disponible lors du d\u00e9marrage.", "Title": "Titre", "Uninstall": "D\u00e9sinstaller", "Update": "Mettre \u00e0 jour", "Update everything": "Tout mettre \u00e0 jour", "Updates": "Mises \u00e0 jour", "Upgradeable to {{getUpgrade(plugin).version}}": "Mise \u00e0 jour possible vers {{getUpgrade(plugin).version}}", "Version": "Version", "Plugins": "Extensions", "Could not load repository version for ajenti-panel.": "Impossible de charger la version d\u00e9p\u00f4t pour ajenti-panel.", "Could not load plugin repository": "Impossible de charger le d\u00e9p\u00f4t de plugins", "Could not load the installed plugin list": "Impossible de charger la liste des plugins install\u00e9s", "All plugins updated": "Tous les plugins ont \u00e9t\u00e9 mis \u00e0 jour", "Done": "Fait", "Installed. A panel restart is required.": "Install\u00e9. Un red\u00e9marrage du panneau est n\u00e9cessaire.", "Restart now": "Red\u00e9marrer maintenant", "Later": "Plus tard", "Some plugins failed to update": "La mise \u00e0 jour de certains plugins a \u00e9chou\u00e9", "Install failed": "\u00c9chec de l'installation", "Warning": "Avertissement", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "Cela supprimera le plugin Plugins. Vous pourrez le r\u00e9installer plus tard en utilisant PIP.", "Continue": "Poursuivre", "Cancel": "Annuler", "Uninstalling": "D\u00e9sinstallation en cours...", "Uninstalled. A panel restart is required.": "D\u00e9sinstall\u00e9. Un red\u00e9marrage du panneau est n\u00e9cessaire.", "Uninstall failed": "\u00c9chec de la d\u00e9sinstallation"}