{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Ajenti base {{ajentiVersion}}, no hay actualizaciones disponibles.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "Ajenti principal {{ajentiVersion}}. Una actualizaci\u00f3n a {{coreUpgradeAvailable}} est\u00e1 disponible.", "Author": "Autor", "Available plugins": "Plugins disponibles", "Close": "Cerrar", "Community": "Comunidad", "Core": "Principal", "Downloads in the last month": "Descargas en el \u00faltimo mes", "Downloads this month": "Descargas en este mes", "Error": "Error", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "Excepci\u00f3n: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Filter": "Filtro", "Homepage": "P\u00e1gina de inicio", "Install": "Instalar", "Installed plugins": "Plugins instalados", "Loading error": "Error al cargar", "Location": "Ubicaci\u00f3n", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "Mensaje: <code>{{selectedInstalledPlugin.crash.message}}</code>", "Name": "Nombre", "Official": "Oficial", "Restart panel": "Reiniciar el panel", "This plugin crashed with the following error:": "Este plugin finalizo de forma abrupta con el siguiente error:", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "Este plugin requiere binarios de la aplicaci\u00f3n <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, que no estaban disponible durante el inicio.", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "Este plugin requiere del plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, que no estaba disponible durante el inicio.", "Title": "T\u00edtulo", "Uninstall": "Desinstalar", "Update": "Actualizar", "Update everything": "Actualizar todo", "Updates": "Actualizaciones", "Upgradeable to {{getUpgrade(plugin).version}}": "Actualizable a {{getUpgrade(plugin).version}}", "Version": "Versi\u00f3n", "Plugins": "Plugins", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}