{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Ajenti s\u00fcr\u00fcm\u00fc {{ajentiVersion}}, yeni y\u00fckseltme yok.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "Ajenti s\u00fcr\u00fcm\u00fc {{ajentiVersion}}. Yeni {{coreUpgradeAvailable}} i\u00e7in bir y\u00fckseltme yap\u0131labilir.", "Author": "Haz\u0131rlayan", "Available plugins": "Kullan\u0131labilir Eklentiler", "Close": "Kapat", "Community": "Topluluk", "Core": "\u00c7ekirdek", "Downloads in the last month": "Son bir ay i\u00e7erisinde indirme", "Downloads this month": "Bu ay indirilenler", "Error": "Hata", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "\u00d6zel durum: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Filter": "Filtre", "Homepage": "Anasayfa", "Install": "Y\u00fckle", "Installed plugins": "Y\u00fckl\u00fc eklentiler", "Loading error": "Y\u00fckleme hatas\u0131", "Location": "Konum", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "Hata olu\u015ftu: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Name": "Ad\u0131", "Official": "Resmi", "Restart panel": "Paneli yeniden ba\u015flat", "This plugin crashed with the following error:": "Bu eklenti a\u015fa\u011f\u0131daki hata ile d\u00fc\u015ft\u00fc:", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "Bu plugin, ba\u015flat\u0131l\u0131rken hata olu\u015fan <code>{{selectedInstalledPlugin.crash.binaryName}}</code> program\u0131na ihtiya\u00e7 duyuyor.", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "Bu eklenti <code>{{selectedInstalledPlugin.crash.pluginName}}</code> gerektirir, ba\u015flang\u0131\u00e7ta kullan\u0131lmayacakt\u0131r.", "Title": "Ba\u015fl\u0131k", "Uninstall": "Kald\u0131r", "Update": "G\u00fcncelle", "Update everything": "Her\u015feyi g\u00fcncelle", "Updates": "G\u00fcncellemeler", "Upgradeable to {{getUpgrade(plugin).version}}": "{{getUpgrade(plugin).version}} versiyonuna g\u00fcncellenebilir", "Version": "S\u00fcr\u00fcm", "Plugins": "Eklentiler", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}