{"": "", "Ajenti core {{ajentiVersion}}, no upgrades available.": "Inti Ajenti {{ajentiVersion}}, tidak ada upgrade yang tersedia.", "Ajenti core {{ajentiVersion}}. An upgrade to {{coreUpgradeAvailable}} is available.": "Ajenti inti {{ajentiVersion}}. Upgrade ke {{coreUpgradeAvailable}} tersedia.", "Author": "Penulis", "Available plugins": "Plugin yang tersedia", "Close": "Tutup", "Community": "Masyarakat", "Core": "Core", "Downloads in the last month": "Download di bulan lalu", "Downloads this month": "Download bulan ini", "Error": "Kesalahan", "Exception: <code>{{selectedInstalledPlugin.crash.cls}}</code>": "Pengecualian: <code>{{selectedInstalledPlugin.crash.cls}}</code>", "Filter": "Saringan", "Homepage": "Beranda", "Install": "Pasang", "Installed plugins": "Plugin Terpasang", "Loading error": "Kesalahan memuat", "Location": "Lokasi", "Message: <code>{{selectedInstalledPlugin.crash.message}}</code>": "Pesan: <code>{{selectedInstalledPlugin.crash.message}}</code>", "Name": "Nama", "Official": "Resmi", "Restart panel": "Mengulang Panel", "This plugin crashed with the following error:": "Plugin ini mengalami kesalahan berikut:", "This plugin requires application binary <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, which was unavailable during startup.": "Plugin ini memerlukan aplikasi biner <code>{{selectedInstalledPlugin.crash.binaryName}}</code>, yang tidak tersedia saat startup.", "This plugin requires plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, which was unavailable during startup.": "Plugin ini membutuhkan plugin <code>{{selectedInstalledPlugin.crash.pluginName}}</code>, yang tidak tersedia saat startup.", "Title": "Judul", "Uninstall": "Hapus", "Update": "Memperbarui", "Update everything": "Perbarui semuanya", "Updates": "Pembaruan", "Upgradeable to {{getUpgrade(plugin).version}}": "Dapat ditingkatkan versinya ke {{getUpgrade(plugin).version}}", "Version": "Versi", "Plugins": "Plugin", "Could not load repository version for ajenti-panel.": "", "Could not load plugin repository": "", "Could not load the installed plugin list": "", "All plugins updated": "", "Done": "", "Installed. A panel restart is required.": "", "Restart now": "", "Later": "", "Some plugins failed to update": "", "Install failed": "", "Warning": "", "This will remove the Plugins plugin. You can reinstall it later using PIP.": "", "Continue": "", "Cancel": "", "Uninstalling": "", "Uninstalled. A panel restart is required.": "", "Uninstall failed": ""}